#include <windows.h>
#include <stdio.h>
#include "FTD2XX.H"

//////////////////////////////////////////////////////////////////////////

#define RF25x_INTERNAL_NAME	"RF25x"

//////////////////////////////////////////////////////////////////////////

#ifdef __cplusplus
extern "C" {
#endif


/************************************************************************/
/* Structures                                                           */
/************************************************************************/


typedef struct _RF62x_HELLO_ANSWER_
{
	BYTE	bDeviceType;
	BYTE	bDeviceModificaton;
	WORD	wDeviceSerial;
	WORD	wDeviceMaxDistance;
	WORD	wDeviceRange;
} RF25xHELLOANSWER, *LPRF25xHELLOANSWER;

//////////////////////////////////////////////////////////////////////////

/************************************************************************/
/* Definitions                                                          */
/************************************************************************/

///////////////////////////////////////////////////////// Address / Length ////////////////
#define	RF25x_PARAMETER_POWER_STATE						((0x00) | ((0x01) << 8))
#define	RF25x_PARAMETER_PRIORITY_AND_SYNC				((0x01) | ((0x01) << 8))
#define	RF25x_PARAMETER_NETWORK_ADDRESS					((0x02) | ((0x01) << 8))
#define	RF25x_PARAMETER_BAUDRATE						((0x03) | ((0x01) << 8))
#define	RF25x_PARAMETER_PIXEL_SIZE						((0x04) | ((0x02) << 8))
#define	RF25x_PARAMETER_DATUM_POINT						((0x07) | ((0x03) << 8))
#define	RF25x_PARAMETER_SAMPLING_PERIOD					((0x0A) | ((0x02) << 8))
#define	RF25x_PARAMETER_BEGIN_ANALOG_RANGE				((0x0C) | ((0x02) << 8))
#define	RF25x_PARAMETER_END_ANALOG_RANGE				((0x0E) | ((0x02) << 8))
//////////////////////////////////////////////////////////////////////////

/************************************************************************/
/* Functions                                                            */
/************************************************************************/

/************************************************************************/
/* RS-232 functions                                                     */
/************************************************************************/

BOOL	RF25x_OpenPort(			
			LPCSTR					lpPort_Name, 
			DWORD					dwSpeed, 
			HANDLE *				lpHandle 
			);

BOOL	RF25x_GetTimeouts(			
			HANDLE					hHandle, 
			LPCOMMTIMEOUTS			lpctto, 
			DWORD *					lpdwIntTimeout 
			);

BOOL	RF25x_SetTimeouts(			
			HANDLE					hHandle, 
			LPCOMMTIMEOUTS			lpctto, 
			DWORD					dwIntTimeout 
			);

BOOL	RF25x_ClosePort( 
			HANDLE					hHandle 
			);

BOOL	RF25x_HelloCmd(		
			HANDLE					hCOM, 
			BYTE					bAddress, 
			LPRF25xHELLOANSWER		lprfHelloAnswer 
			);

BOOL	RF25x_ReadParameter(		
			HANDLE					hCOM, 
			BYTE					bAddress, 
			WORD					wParameter,
			DWORD *					lpdwValue 
			);

BOOL	RF25x_WriteParameter(		
			HANDLE					hCOM, 
			BYTE					bAddress, 
			WORD					wParameter,
			DWORD					dwValue 
			);

BOOL	RF25x_ReadCustomParameter(		
			HANDLE					hCOM, 
			BYTE					bAddress, 
			BYTE					bParameterAddress,
			BYTE					bParameterSize,
			void *					lpValue 
			);

BOOL	RF25x_WriteCustomParameter(		
			HANDLE					hCOM, 
			BYTE					bAddress, 
			BYTE					bParameterAddress,
			BYTE					bParameterSize,
			void *					lpValue 
			);

BOOL	RF25x_FlushToFlash(		
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_RestoreFromFlash(		
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_LockResult(		
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_Measure(	
			HANDLE					hCOM, 
			BYTE					bAddress, 
			DWORD *					lpdwValue 
			);

BOOL	RF25x_StartStream(	
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_StopStream(	
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_GetStreamMeasure(	
			HANDLE					hCOM, 
			DWORD *					lpdwValue 
			);

BOOL	RF25x_SetDatumPoint(		
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_CustomCmd(	
			HANDLE					hCOM, 
			char *					pcInData, 
			DWORD					dwInSize, 
			char *					pcOutData, 
			DWORD *					pdwOutSize
			);

/************************************************************************/
/* FTDI functions		                                                */
/************************************************************************/

BOOL	RF25x_FTDI_OpenPort(		
			LPCSTR					lpPort_Name, 
			DWORD					dwSpeed, 
			FT_HANDLE *				lpftHandle 
			);

BOOL	RF25x_FTDI_GetTimeouts(			
			FT_HANDLE				hHandle, 
			FTTIMEOUTS *			lpctto, 
			DWORD *					lpdwIntTimeout 
			);

BOOL	RF25x_FTDI_SetTimeouts(			
			FT_HANDLE				hHandle, 
			FTTIMEOUTS *			lpctto, 
			DWORD					dwIntTimeout 
			);

BOOL	RF25x_FTDI_ClosePort( 
			FT_HANDLE				hftHandle 
			);

BOOL	RF25x_FTDI_HelloCmd(	
			FT_HANDLE				hCOM, 
			BYTE					bAddress, 
			LPRF25xHELLOANSWER		lprfHelloAnswer 
			);

BOOL	RF25x_FTDI_ReadParameter(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress, 
			WORD					wParameter,
			DWORD *					lpdwValue 
			);

BOOL	RF25x_FTDI_WriteParameter(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress, 
			WORD					wParameter,
			DWORD					dwValue 
			);

BOOL	RF25x_FTDI_ReadCustomParameter(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress, 
			BYTE					bParameterAddress,
			BYTE					bParameterSize,
			void *					lpValue 
			);

BOOL	RF25x_FTDI_WriteCustomParameter(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress, 
			BYTE					bParameterAddress,
			BYTE					bParameterSize,
			void *					lpValue 
			);

BOOL	RF25x_FTDI_FlushToFlash(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_FTDI_RestoreFromFlash(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_FTDI_LockResult(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_FTDI_Measure( 
			FT_HANDLE				hCOM, 
			BYTE					bAddress, 
			DWORD *					lpdwValue 
			);

BOOL	RF25x_FTDI_StartStream(	
			FT_HANDLE				hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_FTDI_StopStream(	
			HANDLE					hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_FTDI_GetStreamMeasure(	
			FT_HANDLE				hCOM, 
			DWORD *					lpdwValue 
			);

BOOL	RF25x_FTDI_SetDatumPoint(		
			FT_HANDLE				hCOM, 
			BYTE					bAddress
			);

BOOL	RF25x_FTDI_CustomCmd( 
			FT_HANDLE				hCOM, 
			char *					pcInData, 
			DWORD					dwInSize, 
			char *					pcOutData, 
			DWORD *					pdwOutSize
			);

//////////////////////////////////////////////////////////////////////////

#ifdef __cplusplus
}
#endif

//////////////////////////////////////////////////////////////////////////